@@ -449,7 +449,7 @@ int main(int argc, char* argv[])
                 fprintf(stderr, "%s", string_c_str(gErrMsg));
             }
             else if(rcode != 0) {
-                fprintf(stderr, "return code is not 0\n");
+                fprintf(stderr, "return code is %d\n", rcode);
                 
                 /// ヒストリに追加 ///
                 add_history(buf);
