@@ -190,6 +190,8 @@ int sRFd_read_oneline(sRFd* self, string_obj* str, enum eLineField lf);
 int sRFd_read_oneline_num(sRFd* self, string_obj* str, int line_num, enum eLineField lf);
 int sRFd_read_oneline_preserve(sRFd* self, string_obj* str, enum eLineField lf);
 int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num, enum eLineField lf);
+int sRFd_read_onechar_num(sRFd* self, string_obj* str, int char_num);
+int sRFd_read_onechar_preserve_num(sRFd* self, string_obj* str, int char_num);
 int sRFd_read_all_to_buffer(sRFd* self);
 void sRFd_set_buffer(sRFd* self, char* buffer);
 
